Internal Function that translates programmatic designs into optimized coding statements for faster calculations
translate.fn.calls(
the.statement,
function.name = "get(",
envir = .GlobalEnv,
...
)original coding statement to perform the required calculation. Must be provided as a character value.
Name of the function to be translated to an optimized form. Parameter values should be either 'get(' or 'eval('. 'get(' is set as default
Specify the environment for the required function. .GlobalEnv is set as default
provision for additional arguments